
unit UKelsoTi ; {Unit SGP_Time;}

{           Author:  Dr TS Kelso }
{ Original Version:  1992 Jun 02 }
{ Current Revision:  2000 Jan 22 }
{ Modified for Y2K:  1999 Mar 07 }
{          Version:  2.05 }
{        Copyright:  1992-1999, All Rights Reserved }
{ Version 1.50 added Y2K support. Due to limitations in the current
  format of the NORAD two-line element sets, however, only dates
  through 2056 December 31/2359 UTC are valid. }
{ Version 1.60 modifies Calendar_Date to ensure date matches time
  resolution and modifies Time_of_Day to make it more robust. }
{ Version 2.00 adds Julian_Date, Date_Time, and Check_Date to support
  checking for valid date/times, permitting the use of Time_to_UTC and
  Time_from_UTC for UTC/local time conversions. }
{ Version 2.05 modifies UTC_offset to allow non-integer offsets. }

INTERFACE

  Uses
    UKelsoMa ; {SGP_Math, for Modulus }

const
  xmnpda   =  1440.0;        {Minutes per day}
  secday   = 86400.0;        {Seconds per day}
  omega_E  = 1.00273790934;  {Earth rotations per sidereal day (non-constant)}
  omega_ER = omega_E*2*pi;   {Earth rotation, radians per sidereal day}

var
  ds50 : double;

Function Julian_Date_of_Year(year : double) : double;

Function Julian_Date_of_Epoch(epoch : double) : double; {Modified for Y2K}

Function ThetaG(epoch : double) : double;               {Modified for Y2K}

Function ThetaG_JD(jd : double) : double;

IMPLEMENTATION

Function Julian_Date_of_Year(year : double) : double;
  { Astronomical Formulae for Calculators, Jean Meeus, pages 23-25 }
  { Calculate Julian Date of 0.0 Jan year }
  var
    A,B   : longint;
  begin
  year := year - 1;
  A := Trunc(year/100);
  B := 2 - A + Trunc(A/4);
  Julian_Date_of_Year := Trunc(365.25 * year)
                       + Trunc(30.6001 * 14)
                       + 1720994.5 + B;
  end; {Function Julian_Date_of_Year}

Function Julian_Date_of_Epoch(epoch : double) : double;
  var
    year,day : double;
  begin
{ Modification to support Y2K }
{ Valid 1957 through 2056 }
  year := Int(epoch*1E-3);
  if year < 57 then
    year := year + 2000
  else
    year := year + 1900;
{ End modification }
  day  := Frac(epoch*1E-3)*1E3;
  Julian_Date_of_Epoch := Julian_Date_of_Year(year) + day;
  end; {Function Julian_Date_of_Epoch}

Function ThetaG(epoch : double) : double;
{ Reference:  The 1992 Astronomical Almanac, page B6. }
  var
    year,day,UT,jd,TU,GMST : double;
  begin
{ Modification to support Y2K }
{ Valid 1957 through 2056 }
  year := Int(epoch*1E-3);
  if year < 57 then
    year := year + 2000
  else
    year := year + 1900;
{ End modification }
  day  := Frac(epoch*1E-3)*1E3;
  UT   := Frac(day);
  day  := Int(day);
  jd   := Julian_Date_of_Year(year) + day;
  TU   := (jd - 2451545.0)/36525;
  GMST := 24110.54841 + TU * (8640184.812866 + TU * (0.093104 - TU * 6.2E-6));
  GMST := Modulus(GMST + secday*omega_E*UT,secday);
  ThetaG := 2*pi * GMST/secday;
  ds50 := jd - 2433281.5 + UT;
  end; {Function ThetaG}

Function ThetaG_JD(jd : double) : double;
{ Reference:  The 1992 Astronomical Almanac, page B6. }
  var
    UT,TU,GMST : double;
  begin
  UT   := Frac(jd + 0.5);
  jd   := jd - UT;
  TU   := (jd - 2451545.0)/36525;
  GMST := 24110.54841 + TU * (8640184.812866 + TU * (0.093104 - TU * 6.2E-6));
  GMST := Modulus(GMST + secday*omega_E*UT,secday);
  ThetaG_JD := 2*pi * GMST/secday;
  end; {Function ThetaG_JD}

end.
