{
 Purpose:

    Computation of the Moon's position

 Notes:

   This software is protected by national and international copyright. 
   Any unauthorized use; reproduction or modificaton is unlawful and 
   will be prosecuted. Commercial and non-private application of the 
   software in any form is strictly prohibited unless otherwise granted
   by the authors.
   
 (c) 1999 Oliver Montenbruck; Thomas Pfleger
}

unit UnForMup ;

interface

procedure MoonBrownPos ( tmjd  : Extended ;
                         var  lambda , beta , range  : Extended ) ;

procedure SimpleMoon ( tmjd  : Extended ;
                       var  v , b ,r  : Extended ) ;

implementation

uses
  UnConTyp ; { const SecRad }

{
  MoonBrownPos

        Computes the Moon's ecliptic position using Brown's theory
          (Improved Lunar Ephemeris)

 Input:

   tmjd         time in modified julian day

 <return>:   geocentric spheric position of the Moon (in [radian,radian,km])
             referred to the ecliptic and equinox of date

 Notes: Light-time is already taken into account
}

procedure MoonBrownPos ( tmjd  : Extended ;
                         var  lambda , beta , range  : Extended ) ;
var
  fam,fal,fap,faf,fad  : Extended ; { fundamental argument lambda l l' F D }
  al,az,an,ag,ap   : Extended ; { series dlambda dS N dgamma1C dSinpi }
  u,s,c,ufs  : Extended ;           { angle sinus cosinus }
  dt,dr,dgam  : Extended ;
  fl1,fl2,fl3,fl4  : Extended ;
  fp1,fp2,fp3  : Extended ;
  ff1,ff2,ff3,ff4  : Extended ;
  s1,s2,s3,s4,s5,s6,s7   : Extended ;

begin

  dt:=(tmjd-51544.5)/36525.0; { time in Julian centuries since J2000 }

  dgam:=-3332.0e-9*Sin(Pi22*(0.59734-5.37261*dt))
         -539.0e-9*Sin(Pi22*(0.35498-5.37899*dt))
          -64.0e-9*Sin(Pi22*(0.39943-5.37511*dt));

  fl1:=1.000002208; { factor for terms with variable l power 1 }
  fl2:=fl1*fl1;     { factor for terms with variable l power 2 }
  fl3:=fl2*fl1;     { factor for terms with variable l power 3 }
  fl4:=fl3*fl1;     { factor for terms with variable l power 4 }

  fp1:=0.997504612-0.002495388*dt; { factor for terms with var. l' power 1 }
  fp2:=fp1*fp1;     { factor for terms with variable l' power 2 }
  fp3:=fp2*fp1;     { factor for terms with variable l' power 3 }

  ff1:=1.000002708+139.978*dgam; { factor for terms with variable F power 1 }
  ff2:=ff1*ff1;     { factor for terms with variable F power 2 }
  ff3:=ff2*ff1;     { factor for terms with variable F power 3 }
  ff4:=ff3*ff1;     { factor for terms with variable F power 4 }

  { Mean arguments of the lunar orbit (incl. longperiodic corrections)
    L0 fam
    l  fal
    l' fap
    F  faf
    D  fad
    L0 mean longitude of the Moon
    l  mean anomaly of the Moon     l' mean anomaly of the Sun
    F  mean distance from the node  D  mean elongation from the Sun }

  fam:=Pi22*Frac(0.60643382+(1336.85522467-0.00000313*dt)*dt);
  fal:=Pi22*Frac(0.37489701+(1325.55240982+0.00002565*dt)*dt);
  fap:=Pi22*Frac(0.99312619+(  99.99735956-0.00000044*dt)*dt);
  faf:=Pi22*Frac(0.25909118+(1342.22782980-0.00000892*dt)*dt);
  fad:=Pi22*Frac(0.82736186+(1236.85308708-0.00000397*dt)*dt);

  { additive terms to fundamental arguments longperiodic corrections }

  s1:=Sin(1.24614+0.35255*dt);  { sinus argument radian     20.1996 degree }
  s2:=Sin(1.75106+0.28325*dt);  { sinus argument radian     16.2288 degree }
  s3:=Sin(1.05727-2.31868*dt);  { sinus argument radian   -132.8508 degree }
  s4:=Sin(2.18240-33.7571*dt);  { sinus argument radian  -1934.1396 degree }
  s5:=Sin(0.65961-33.79719*dt); { sinus argument radian  -1936.4364 degree }
  s6:=Sin(2.68173-2.62983*dt);  { sinus argument radian   -150.678  degree }
  s7:=Sin(0.93890-33.77281*dt); { sinus argument radian  -1935.0396 degree }
  dr:=0.31*s2+14.27*s3;
  fam:=fam+SecRad*(0.84*s1+dr+7.26*s4+0.28*s5+0.24*s6); { lambda rd }
  fal:=fal+SecRad*(2.94*s1+dr+9.34*s4+1.12*s5+0.83*s6); { l  radian }
  fap:=fap-SecRad*(6.4*s1+1.89*s6);                     { l' radian }
  faf:=faf+SecRad*(0.21*s1+dr-88.7*s4-15.3*s5+0.24*s6-1.86*s7); { F }
  fad:=fad+SecRad*(7.24*s1+dr+7.26*s4+0.28*s5+2.13*s6); { D  radian }

  { Solar perturbations }

  al:=0.0;            az:=0.0;       
  ag:=0.0;         ap:=3422.700;     { l l'F D }
  u:=4*fad;
  s:=Sin(u); c:=Cos(u);                         { 0 0 0 4 }
  al:=al+13.902*s;    az:=az+14.06*s;  
  ag:=ag-0.001*c;  ap:=ap+0.2607*c;  { 0 0 0 4 }
  u:=3*fad;
  s:=Sin(u); c:=Cos(u);                         { 0 0 0 3 }
  al:=al+0.403*s;     az:=az-4.01*s; 
  ag:=ag+0.394*c;  ap:=ap+0.0023*c;  { 0 0 0 3 }
  u:=2*fad;
  s:=Sin(u); c:=Cos(u);                         { 0 0 0 2 }
  al:=al+2369.912*s;  az:=az+2373.36*s;
  ag:=ag+0.601*c;  ap:=ap+28.2333*c; { 0 0 0 2 }
  u:=fad;
  s:=Sin(u); c:=Cos(u);                         { 0 0 0 1 }
  al:=al-125.154*s;   az:=az-112.79*s;
  ag:=ag-0.725*c;  ap:=ap-0.9781*c;  { 0 0 0 1 }
  u:=fal+4*fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0 4 }
  al:=al+1.979*s;     az:=az+6.98*s;   
  ag:=ag-0.445*c;  ap:=ap+0.0433*c;  { 1 0 0 4 }
  u:=fal+2*fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0 2 }
  al:=al+191.953*s;   az:=az+192.72*s; 
  ag:=ag+0.029*c;  ap:=ap+3.0861*c;  { 1 0 0 2 }
  u:=fal+fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0 1 }
  al:=al-8.466*s;     az:=az-13.51*s;  
  ag:=ag+0.455*c;  ap:=ap-0.1093*c;  { 1 0 0 1 }
  u:=fal;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0 0 }
  al:=al+22639.500*s; az:=az+22609.07*s;
  ag:=ag+0.079*c;  ap:=ap+186.5398*c; {1 0 0 0 }
  u:=fal-fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0-1 }
  al:=al+18.609*s;    az:=az+3.59*s;   
  ag:=ag-0.094*c;  ap:=ap+0.0118*c;  { 1 0 0-1 }
  u:=fal-2*fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0-2 }
  al:=al-4586.465*s;  az:=az-4578.13*s;
  ag:=ag-0.077*c;  ap:=ap+34.3117*c; { 1 0 0-2 }
  u:=fal-3*fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0-3 }
  al:=al+3.215*s;     az:=az+5.44*s;   
  ag:=ag+0.192*c;  ap:=ap-0.0386*c;  { 1 0 0-3 }
  u:=fal-4*fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0-4 }
  al:=al-38.428*s;    az:=az-38.64*s;  
  ag:=ag+0.001*c;  ap:=ap+0.6008*c;  { 1 0 0-4 }
  u:=fal-6*fad;
  s:=fl1*Sin(u); c:=fl1*Cos(u);                         { 1 0 0-6 }
  al:=al-0.393*s;     az:=az-1.43*s;   
  ag:=ag-0.092*c;  ap:=ap+0.0086*c;  { 1 0 0-6 }
  u:=fap+4*fad;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al-0.289*s;     az:=az-1.59*s;   
  ag:=ag+0.123*c;  ap:=ap-0.0053*c;  { 0 1 0 4 }
  u:=fap+2*fad;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al-24.420*s;    az:=az-25.10*s;  
  ag:=ag+0.040*c;  ap:=ap-0.3000*c;  { 0 1 0 2 }
  u:=fap+fad;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al+18.023*s;    az:=az+17.93*s;  
  ag:=ag+0.007*c;  ap:=ap+0.1494*c;  { 0 1 0 1 }
  u:=fap;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al-668.146*s;   az:=az-126.98*s; 
  ag:=ag-1.302*c;  ap:=ap-0.3997*c;  { 0 1 0 0 }
  u:=fap-fad;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al+0.560*s;     az:=az+0.32*s;   
  ag:=ag-0.001*c;  ap:=ap-0.0037*c;  { 0 1 0-1 }
  u:=fap-2*fad;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al-165.145*s;   az:=az-165.06*s; 
  ag:=ag+0.054*c;  ap:=ap+1.9178*c;  { 0 1 0-2 }
  u:=fap-4*fad;
  s:=fp1*Sin(u); c:=fp1*Cos(u);
  al:=al-1.877*s;     az:=az-6.46*s;   
  ag:=ag-0.416*c;  ap:=ap+0.0339*c;  { 0 1 0-4 }
  u:=2*fal+4*fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al+0.213*s;     az:=az+1.02*s;  
  ag:=ag-0.074*c;  ap:=ap+0.0054*c;  { 2 0 0 4 }
  u:=2*fal+2*fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al+14.387*s;    az:=az+14.78*s;  
  ag:=ag-0.017*c;  ap:=ap+0.2833*c;  { 2 0 0 2 }
  u:=2*fal+fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al-0.586*s;     az:=az-1.20*s;  
  ag:=ag+0.054*c;  ap:=ap-0.0100*c;  { 2 0 0 1 }
  u:=2*fal;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al+769.016*s;   az:=az+767.96*s; 
  ag:=ag+0.107*c;  ap:=ap+10.1657*c; { 2 0 0 0 }
  u:=2*fal-fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al+1.750*s;     az:=az+2.01*s;   
  ag:=ag-0.018*c;  ap:=ap+0.0155*c;  { 2 0 0-1 }
  u:=2*fal-2*fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al-211.656*s;   az:=az-152.53*s; 
  ag:=ag+5.679*c;  ap:=ap-0.3039*c;  { 2 0 0-2 }
  u:=2*fal-3*fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al+1.225*s;     az:=az+0.91*s;   
  ag:=ag-0.030*c;  ap:=ap-0.0088*c;  { 2 0 0-3 }
  u:=2*fal-4*fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al-30.773*s;    az:=az-34.07*s;  
  ag:=ag-0.308*c;  ap:=ap+0.3722*c;  { 2 0 0-4 }
  u:=2*fal-6*fad;
  s:=fl2*Sin(u); c:=fl2*Cos(u);
  al:=al-0.570*s;     az:=az-1.40*s;  
  ag:=ag-0.074*c;  ap:=ap+0.0109*c;  { 2 0 0-6 }
  u:=fal+fap+2*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);    { 1 1 0 2 }
  al:=al-2.921*s;     az:=az-11.75*s;  
  ag:=ag+0.787*c;  ap:=ap-0.0484*c;
  u:=fal+fap+fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);    { 1 1 0 1 }
  al:=al+1.267*s;     az:=az+1.52*s;   
  ag:=ag-0.022*c;  ap:=ap+0.0164*c;
  u:=fal+fap;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al-109.673*s;   az:=az-115.18*s; 
  ag:=ag+0.461*c;  ap:=ap-0.9490*c;  { 1 1 0 0 }
  u:=fal+fap-2*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al-205.962*s;   az:=az-182.36*s; 
  ag:=ag+2.056*c;  ap:=ap+1.4437*c;  { 1 1 0-2 }
  u:=fal+fap-3*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al+0.233*s;     az:=az+0.36*s;   
  ag:=ag+0.012*c;  ap:=ap-0.0025*c;  { 1 1 0-3 }
  u:=fal+fap-4*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al-4.391*s;     az:=az-9.66*s;   
  ag:=ag-0.471*c;  ap:=ap+0.0673*c;  { 1 1 0-4 }
  u:=fal-fap+4*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al+0.283*s;     az:=az+1.53*s;   
  ag:=ag-0.111*c;  ap:=ap+0.0060*c;  { 1-1 0+4 }
  u:=fal-fap+2*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al+14.577*s;    az:=az+31.70*s;  
  ag:=ag-1.540*c;  ap:=ap+0.2302*c;  { 1-1 0 2 }
  u:=fal-fap;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al+147.687*s;   az:=az+138.76*s; 
  ag:=ag+0.679*c;  ap:=ap+1.1528*c;  { 1-1 0 0 }
  u:=fal-fap-fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al-1.089*s;     az:=az+0.55*s;   
  ag:=ag+0.021*c; {0.0   ;}          { 1-1 0-1 }
  u:=fal-fap-2*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al+28.475*s;    az:=az+23.59*s;  
  ag:=ag-0.443*c;  ap:=ap-0.2257*c;  { 1-1 0-2 }
  u:=fal-fap-3*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al-0.276*s;     az:=az-0.38*s;   
  ag:=ag-0.006*c;  ap:=ap-0.0036*c;  { 1-1 0-3 }
  u:=fal-fap-4*fad;
  s:=fl1*fp1*Sin(u); c:=fl1*fp1*Cos(u);
  al:=al+0.636*s;     az:=az+2.27*s;   
  ag:=ag+0.146*c;  ap:=ap-0.0102*c;  { 1-1 0-4 }
  u:=2*fap+2*fad;
  s:=fp2*Sin(u); c:=fp2*Cos(u);
  al:=al-0.189*s;     az:=az-1.68*s;   
  ag:=ag+0.131*c;  ap:=ap-0.0028*c;  { 0 2 0 2 }
  u:=2*fap;
  s:=fp2*Sin(u); c:=fp2*Cos(u);
  al:=al-7.486*s;     az:=az-0.66*s;   
  ag:=ag-0.037*c;  ap:=ap-0.0086*c;  { 0 2 0 0 }
  u:=2*fap-2*fad;
  s:=fp2*Sin(u); c:=fp2*Cos(u);
  al:=al-8.096*s;     az:=az-16.35*s;  
  ag:=ag-0.740*c;  ap:=ap+0.0918*c;  { 0 2 0-2 }
  u:=2*faf+2*fad;
  s:=ff2*Sin(u); c:=ff2*Cos(u);
  al:=al-5.741*s;     az:=az-0.04*s; 
 { 0.0  ;         } ap:=ap-0.0009*c;  { 0 0 2 2 }
  u:=2*faf+fad;
  s:=ff2*Sin(u); c:=ff2*Cos(u);       { 0 0 2 1 }
  al:=al+0.255*s;   { 0.0 ;         
     0.0  ;           0.0   ; }
  u:=2*faf;
  s:=ff2*Sin(u); c:=ff2*Cos(u);        { 0 0 2 0 }
  al:=al-411.608*s;   az:=az-0.20*s; 
  { 0.0  ;         } ap:=ap-0.0124*c;
  u:=2*faf-fad;
  s:=ff2*Sin(u); c:=ff2*Cos(u);
  al:=al+0.584*s;     az:=az+0.84*s; 
  { 0.0  ;         } ap:=ap+0.0071*c;  { 0 0 2-1 }
  u:=2*faf-2*fad;
  s:=ff2*Sin(u); c:=ff2*Cos(u);
  al:=al-55.173*s;    az:=az-52.14*s;
  { 0.0  ;         } ap:=ap-0.1052*c;  { 0 0 2-2 }
  u:=2*faf-3*fad;
  s:=ff2*Sin(u); c:=ff2*Cos(u);
  al:=al+0.254*s;     az:=az+0.25*s; 
  { 0.0  ;         } ap:=ap-0.0017*c;  { 0 0 2-3 }
  u:=2*faf-4*fad;
  s:=ff2*Sin(u); c:=ff2*Cos(u);
  al:=al+0.025*s;     az:=az-1.67*s; 
  { 0.0  ;         } ap:=ap+0.0031*c;  { 0 0 2-4 }
  u:=3*fal+2*fad;
  s:=fl3*Sin(u); c:=fl3*Cos(u);
  al:=al+1.060*s;     az:=az+2.96*s;   
  ag:=ag-0.166*c;  ap:=ap+0.0243*c;  { 3 0 0+2 }
  u:=3*fal;
  s:=fl3*Sin(u); c:=fl3*Cos(u);
  al:=al+36.124*s;    az:=az+50.64*s;  
  ag:=ag-1.300*c;  ap:=ap+0.6215*c;  { 3 0 0 0 }
  u:=3*fal-2*fad;
  s:=fl3*Sin(u); c:=fl3*Cos(u);
  al:=al-13.193*s;    az:=az-16.40*s;  
  ag:=ag+0.258*c;  ap:=ap-0.1187*c;  { 3 0 0-2 }
  u:=3*fal-4*fad;
  s:=fl3*Sin(u); c:=fl3*Cos(u);
  al:=al-1.187*s;     az:=az-0.74*s;   
  ag:=ag+0.042*c;  ap:=ap+0.0074*c;  { 3 0 0-4 }
  u:=3*fal-6*fad;
  s:=fl3*Sin(u); c:=fl3*Cos(u);
  al:=al-0.293*s;     az:=az-0.31*s;   
  ag:=ag-0.002*c;  ap:=ap+0.0046*c;  { 3 0 0-6 }
  u:=2*fal+fap+2*fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al-0.290*s;     az:=az-1.45*s;   
  ag:=ag+0.116*c;  ap:=ap-0.0051*c;  { 2 1 0 2 }
  u:=2*fal+fap;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al-7.649*s;     az:=az-10.56*s;  
  ag:=ag+0.259*c;  ap:=ap-0.1038*c;  { 2 1 0 0 }
  u:=2*fal+fap-2*fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al-8.627*s;     az:=az-7.59*s;   
  ag:=ag+0.078*c;  ap:=ap-0.0192*c;  { 2 1 0-2 }
  u:=2*fal+fap-4*fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al-2.740*s;     az:=az-2.54*s;   
  ag:=ag+0.022*c;  ap:=ap+0.0324*c;  { 2 1 0-4 }
  u:=2*fal-fap+2*fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al+1.181*s;     az:=az+3.32*s;   
  ag:=ag-0.212*c;  ap:=ap+0.0213*c;  { 2-1 0+2 }
  u:=2*fal-fap;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al+9.703*s;     az:=az+11.67*s;  
  ag:=ag-0.151*c;  ap:=ap+0.1268*c;  { 2-1 0 0 }
  u:=2*fal-fap-fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al-0.352*s;     az:=az-0.37*s;   
  ag:=ag+0.001*c;  ap:=ap-0.0028*c;  { 2-1 0-1 }
  u:=2*fal-fap-2*fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al-2.494*s;     az:=az-1.17*s;   
  ag:=ag-0.003*c;  ap:=ap-0.0017*c;  { 2-1 0-2 }
  u:=2*fal-fap-4*fad;
  s:=fl2*fp1*Sin(u); c:=fl2*fp1*Cos(u);
  al:=al+0.360*s;     az:=az+0.20*s;   
  ag:=ag-0.012*c;  ap:=ap-0.0043*c;  { 2-1 0-4 }
  u:=fal+2*fap;
  s:=fl1*fp2*Sin(u); c:=fl1*fp2*Cos(u);
  al:=al-1.167*s;     az:=az-1.25*s;   
  ag:=ag+0.008*c;  ap:=ap-0.0106*c;  { 1 2 0 0 }
  u:=fal+2*fap-2*fad;
  s:=fl1*fp2*Sin(u); c:=fl1*fp2*Cos(u);
  al:=al-7.412*s;     az:=az-6.12*s;   
  ag:=ag+0.117*c;  ap:=ap+0.0484*c;  { 1 2 0-2 }
  u:=fal+2*fap-4*fad;
  s:=fl1*fp2*Sin(u); c:=fl1*fp2*Cos(u);
  al:=al-0.311*s;     az:=az-0.65*s;   
  ag:=ag-0.032*c;  ap:=ap+0.0044*c;  { 1 2 0-4 }
  u:=fal-2*fap+2*fad;
  s:=fl1*fp2*Sin(u); c:=fl1*fp2*Cos(u);
  al:=al+0.757*s;     az:=az+1.82*s;   
  ag:=ag-0.105*c;  ap:=ap+0.0112*c;  { 1-2 0 2 }
  u:=fal-2*fap;
  s:=fl1*fp2*Sin(u); c:=fl1*fp2*Cos(u);
  al:=al+2.580*s;     az:=az+2.32*s;   
  ag:=ag+0.027*c;  ap:=ap+0.0196*c;  { 1-2 0 0 }
  u:=fal-2*fap-2*fad;
  s:=fl1*fp2*Sin(u); c:=fl1*fp2*Cos(u);
  al:=al+2.533*s;     az:=az+2.40*s;   
  ag:=ag-0.014*c;  ap:=ap-0.0212*c;  { 1-2 0-2 }
  u:=3*fap-2*fad;
  s:=fp3*Sin(u); c:=fp3*Cos(u);
  al:=al-0.344*s;     az:=az-0.57*s;   
  ag:=ag-0.025*c;  ap:=ap+0.0036*c;  { 0 3 0-2 }
  u:=fal+2*faf+2*fad;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al-0.992*s;     az:=az-0.02*s; 
 { 0.0  ;           0.0   ; }         { 1 0 2 2 }
  u:=fal+2*faf;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al-45.099*s;    az:=az-0.02*s;
  { 0.0  ; }         ap:=ap-0.0010*c;  { 1 0 2 0 }
  u:=fal+2*faf-2*fad;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al-0.179*s;     az:=az-9.52*s; 
  { 0.0  ; }         ap:=ap-0.0833*c;  { 1 0 2-2 }
  u:=fal+2*faf-4*fad;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al-0.301*s;     az:=az-0.33*s; 
  { 0.0  ; }         ap:=ap+0.0014*c;  { 1 0 2-4 }
  u:=fal-2*faf+2*fad;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al-6.382*s;     az:=az-3.37*s; 
  { 0.0  ; }         ap:=ap-0.0481*c;  { 1 0-2 2 }
  u:=fal-2*faf;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al+39.528*s;    az:=az+85.13*s; 
 { 0.0  ; }         ap:=ap-0.7136*c;  { 1 0-2 0 }
  u:=fal-2*faf-2*fad;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al+9.366*s;     az:=az+0.71*s;  
 { 0.0  ; }         ap:=ap-0.0112*c;  { 1 0-2-2 }
  u:=fal-2*faf-4*fad;
  s:=fl1*ff2*Sin(u); c:=fl1*ff2*Cos(u);
  al:=al+0.202*s;     az:=az+0.02*s; 
  { 0.0  ;           0.0  }            { 1 0-2-4 }
  u:=fap+2*faf;
  s:=fp1*ff2*Sin(u); c:=fp1*ff2*Cos(u);
  al:=al+0.415*s;     az:=az+0.10*s; 
  { 0.0  ; }         ap:=ap+0.0013*c;  { 0 1 2 0 }
  u:=fap+2*faf-2*fad;
  s:=fp1*ff2*Sin(u); c:=fp1*ff2*Cos(u);
  al:=al-2.152*s;     az:=az-2.26*s;  
 { 0.0  ; }         ap:=ap-0.0066*c;  { 0 1 2-2 }
  u:=fap-2*faf+2*fad;
  s:=fp1*ff2*Sin(u); c:=fp1*ff2*Cos(u);
  al:=al-1.440*s;     az:=az-1.30*s;  
 { 0.0  ; }         ap:=ap+0.0014*c;  { 0 1-2 2 }
  u:=fap-2*faf-2*fad;
  s:=fp1*ff2*Sin(u); c:=fp1*ff2*Cos(u);
  al:=al+0.384*s;     az:=az-0.04*s; 
  { 0.0  ;           0.0  }            { 0 1-2-2 }
  u:=4*fal;
  s:=fl4*Sin(u); c:=fl4*Cos(u);
  al:=al+1.938*s;     az:=az+3.60*s;  
  ag:=ag-0.145*c;  ap:=ap+0.0401*c;  { 4 0 0 0 }
  u:=4*fal-2*fad;
  s:=fl4*Sin(u); c:=fl4*Cos(u);
  al:=al-0.952*s;     az:=az-1.58*s;   
  ag:=ag+0.052*c;  ap:=ap-0.0130*c;  { 4 0 0-2 }
  u:=3*fal+fap;
  s:=fl3*fp1*Sin(u); c:=fl3*fp1*Cos(u);
  al:=al-0.551*s;     az:=az-0.94*s;   
  ag:=ag+0.032*c;  ap:=ap-0.0097*c;  { 3 1 0 0 }
  u:=3*fal+fap-2*fad;
  s:=fl3*fp1*Sin(u); c:=fl3*fp1*Cos(u);
  al:=al-0.482*s;     az:=az-0.57*s;   
  ag:=ag+0.005*c;  ap:=ap-0.0045*c;  { 3 1 0-2 }
  u:=3*fal-fap;
  s:=fl3*fp1*Sin(u); c:=fl3*fp1*Cos(u);
  al:=al+0.681*s;     az:=az+0.96*s;   
  ag:=ag-0.026*c;  ap:=ap+0.0115*c;  { 3-1 0 0 }
  u:=2*fal+2*fap-2*fad;
  s:=fl2*fp2*Sin(u); c:=fl2*fp2*Cos(u);
  al:=al-0.297*s;     az:=az-0.27*s;   
  ag:=ag+0.002*c;  ap:=ap-0.0009*c;  { 2 2 0-2 }
  u:=2*fal-2*fap-2*fad;
  s:=fl2*fp2*Sin(u); c:=fl2*fp2*Cos(u);
  al:=al+0.254*s;     az:=az+0.21*s;   
  ag:=ag-0.003*c; {0.0 }             { 2-2 0-2 }
  u:=fal+3*fap-2*fad;
  s:=fl1*fp3*Sin(u); c:=fl1*fp3*Cos(u);
  al:=al-0.250*s;     az:=az-0.22*s;   
  ag:=ag+0.004*c;  ap:=ap+0.0014*c;  { 1 3 0-2 }
  u:=2*fal+2*faf;
  s:=fl2*ff2*Sin(u); c:=fl2*ff2*Cos(u);
  al:=al-3.996*s;   { 0.0 ;           
   0.0  ; }         ap:=ap+0.0004*c;  { 2 0 2 0 }
  u:=2*fal+2*faf-2*fad;
  s:=fl2*ff2*Sin(u); c:=fl2*ff2*Cos(u);
  al:=al+0.557*s;     az:=az-0.75*s; 
  { 0.0  ; }         ap:=ap-0.0090*c;  { 2 0 2-2 }
  u:=2*fal-2*faf+2*fad;
  s:=fl2*ff2*Sin(u); c:=fl2*ff2*Cos(u);
  al:=al-0.459*s;     az:=az-0.38*s; 
  { 0.0  ; }         ap:=ap-0.0053*c;  { 2 0-2 2 }
  u:=2*fal-2*faf;
  s:=fl2*ff2*Sin(u); c:=fl2*ff2*Cos(u);
  al:=al-1.298*s;     az:=az+0.74*s; 
  { 0.0  ; }         ap:=ap+0.0004*c;  { 2 0-2 0 }
  u:=2*fal-2*faf-2*fad;
  s:=fl2*ff2*Sin(u); c:=fl2*ff2*Cos(u);
  al:=al+0.538*s;     az:=az+1.14*s; 
  { 0.0  ; }         ap:=ap-0.0141*c;  { 2 0-2-2 }
  u:=fal+fap+2*faf;
  s:=fl1*fp1*ff2*Sin(u); c:=fl1*fp1*ff2*Cos(u);
  al:=al+0.263*s;     az:=az+0.02*s; 
  { 0.0  ;           0.0 }             { 1 1 2 0 }
  u:=fal+fap-2*faf-2*fad;
  s:=fl1*fp1*ff2*Sin(u); c:=fl1*fp1*ff2*Cos(u);
  al:=al+0.426*s;     az:=az+0.07*s; 
  { 0.0  ; }         ap:=ap-0.0006*c;  { 1 1-2-2 }
  u:=fal-fap+2*faf;
  s:=fl1*fp1*ff2*Sin(u); c:=fl1*fp1*ff2*Cos(u);
  al:=al-0.304*s;     az:=az+0.03*s; 
  { 0.0  ; }         ap:=ap+0.0003*c;  { 1-1 2 0 }
  u:=fal-fap-2*faf+2*fad;
  s:=fl1*fp1*ff2*Sin(u); c:=fl1*fp1*ff2*Cos(u);
  al:=al-0.372*s;     az:=az-0.19*s; 
  { 0.0  ; }         ap:=ap-0.0027*c;  { 1-1-2 2 }
  u:=4*faf;
  s:=ff4*Sin(u); c:=ff4*Cos(u);
  al:=al+0.418*s;   { 0.0 ;        
    0.0  ;          0.0   ; }            { 0 0 4 0 }
  u:=3*fal+2*faf;
  s:=fl3*ff2*Sin(u); c:=fl3*ff2*Cos(u);
  al:=al-0.330*s;     az:=az-0.04*s; 
 { 0.0  ;   0.0   ;}                   { 3 0 2 0 }

  { Solar perturbations in latitude }
  u:=faf-2*fad;     s:=ff1*Sin(u);  
  an:=-526.069*s;  {-526.069  0 0 1-2 }
  u:=faf-4*fad;     s:=ff1*Sin(u);  
  an:=an-3.352*s;  {  -3.352  0 0 1-4 }
  u:=fal+faf-2*fad; s:=fl1*ff1*Sin(u);
  an:=an+44.297*s; { +44.297 +1 0 1-2 }
  u:=fal+faf-4*fad; s:=fl1*ff1*Sin(u);
  an:=an-6.000*s;  {  -6.000 +1 0 1-4 }
  u:=-fal+faf;      s:=fl1*ff1*Sin(u);
  an:=an+20.599*s; { +20.599 -1 0 1 0 }
  u:=-fal+faf-2*fad;s:=fl1*ff1*Sin(u);
  an:=an-30.598*s; { -30.598 -1 0 1-2 }
  u:=-2*fal+faf;    s:=fl2*ff1*Sin(u);
  an:=an-24.649*s; { -24.649 -2 0 1 0 }
  u:=-2*fal+faf-2*fad; s:=fl2*ff1*Sin(u);
  an:=an-2.0*s; {  -2.000 -2 0 1-2 }
  u:=fap+faf-2*fad; s:=fp1*ff1*Sin(u);
  an:=an-22.571*s; { -22.571  0+1 1-2 }
  u:=-fap+faf-2*fad;s:=fp1*ff1*Sin(u);
  an:=an+10.985*s; { +10.985  0-1 1-2 }

  { planetary: perturbations
    of ecliptic latitude by Venus and Jupiter }
  al:=al+0.82*Sin(Pi22*(0.7736-62.5512*dt))
        +0.31*Sin(Pi22*(0.0466-125.1025*dt))
        +0.35*Sin(Pi22*(0.5785-25.1042*dt))
        +0.66*Sin(Pi22*(0.4591+1335.8075*dt))
        +0.64*Sin(Pi22*(0.3130-91.5680*dt))
        +1.14*Sin(Pi22*(0.1480+1331.2898*dt))
        +0.21*Sin(Pi22*(0.5918+1056.5859*dt))
        +0.44*Sin(Pi22*(0.5784+1322.8595*dt))
        +0.24*Sin(Pi22*(0.2275-5.7374*dt))
        +0.28*Sin(Pi22*(0.2965+2.6929*dt))
        +0.33*Sin(Pi22*(0.3132+6.3368*dt));

  lambda:=fam+SecRad*al; { ecliptic longitude of the Moon in radian }
  ufs:=faf+SecRad*az; { angle S=F+deltaS in radian }
  beta:=SecRad*(ff1*(18519.7+ag)*Sin(ufs)-6.24*Sin(3*ufs)+an); { latitude }
  range:=6378.14/(SecRad*0.999953253*ap); { range in km }

end;

{
 MiniMoon: Computes the Moon's ecliptic position
           using a low precision analytical series

 Input:

   tmjd    time in modified julian day
}

procedure SimpleMoon ( tmjd  : Extended ;
                       var  v , b , r  : Extended ) ;
var
  fam,fal,fap,faf,fad  : Extended ;
  dt,dl,ds,dh,dn,dr    : Extended ;
begin  
  dt:=(tmjd-51544.5)/36525;
  { mean elements of lunar orbit }
  fam:=Frac(0.606433+1336.855225*dt);       { mean longitude [rev] }
  fal:=Pi22*Frac(0.374897+1325.552410*dt);  { Moon's mean anomaly radian }
  fap:=Pi22*Frac(0.993133+  99.997361*dt);  { Sun's mean anomaly  radian }
  fad:=Pi22*Frac(0.827361+1236.853086*dt);  { Diff. long. Moon-Sun }
  faf:=Pi22*Frac(0.259086+1342.227825*dt);  { Dist. from ascending node }
  { perturbations in longitude and latitude }
  dl:=+22640*sin(fal)-4586*sin(fal-2*fad)
      +2370*sin(2*fad)+769*sin(2*fal) 
      -668*sin(fap)-412*sin(2*faf) 
      -212*sin(2*fal-2*fad)-206*sin(fal+fap-2*fad)
      +192*sin(fal+2*fad)-165*sin(fap-2*fap)
      -125*sin(fad)-110*sin(fal+fap)
      +148*sin(fal-fap)-55*sin(2*faf-2*fad);
  ds:=faf+SecRad*(dl+412*sin(2*faf)+541*sin(fap)); 
  dh:=faf-2*fad;
  dn:=-526*sin(dh)+44*sin(fal+dh)-31*sin(-fal+dh)-23*sin(fap+dh) 
      +11*sin(-fap+dh)-25*sin(-2*fal+faf)+21*sin(-fal+faf);
  { ecliptic longitude and latitude }
  v:=Pi22*Frac(fam+dl/1296.0e3);  { longitude [rad] }
  b:=SecRad*(18520.0*sin(ds)+dn); { latitude  [rad] }
  { range with correction for range in arcsec }
  dr:=+3422.70
        +28.233869*Cos(2*fad)
         +3.08589*Cos(fal+2*fad)
       +186.539296*Cos(fal)
        +34.311569*Cos(fal-2*fad)
         +1.916735*Cos(fap-2*fad)
         -0.977818*Cos(fad)
        +10.165933*Cos(2*fal)
         -0.949147*Cos(fal+fap)
         +1.443617*Cos(fal+fap-2*fad);
  r:=6378.14/(0.999953253*SecRad*dr);  { range in km }
end;

end.
